@@ -101,6 +101,7 @@ use std::fmt;
 use std::fs::File;
 use std::io::Write;
 
+use serde_json::{to_value, Map};
 use std::collections::HashMap;
 
 use geojson::{Feature, FeatureCollection, Geometry, Value};
@@ -809,20 +810,27 @@ impl Triangulation {
         let tr = re.unwrap();
         let mut d = std::f64::MAX;
         let mut closest: usize = 0;
-        //-- 1. find triangle and closest vertex from the 3
+        //-- find closest vertex in the triangle containing p
         for each in tr.v.iter() {
-            // println!("{}", each);
             let dtmp = geom::distance2d_squared(&self.stars[*each].pt, &p);
             if dtmp < d {
                 d = dtmp;
                 closest = *each;
             }
         }
-        for each in self.stars[closest].link.iter() {
-            let dtmp = geom::distance2d_squared(&self.stars[*each].pt, &p);
-            if dtmp < d {
-                d = dtmp;
-                closest = *each;
+        loop {
+            let mut found_one_closer = false;
+            for each in self.stars[closest].link.iter() {
+                let dtmp = geom::distance2d_squared(&self.stars[*each].pt, &p);
+                if dtmp < d {
+                    d = dtmp;
+                    closest = *each;
+                    found_one_closer = true;
+                    break;
+                }
+            }
+            if found_one_closer == false {
+                break;
             }
         }
         Some(closest)
@@ -1280,17 +1288,17 @@ impl Triangulation {
                 continue;
             }
             let pt = Geometry::new(Value::Point(vec![self.stars[i].pt[0], self.stars[i].pt[1]]));
-            // let mut attributes = Map::new();
-            // attributes.insert(String::from("id"), to_value(i.to_string()).unwrap());
-            // attributes.insert(
-            //     String::from("written"),
-            //     serde_json::value::Value::Bool(star.written),
-            // );
+            let mut attributes = Map::new();
+            attributes.insert(String::from("id"), to_value(i.to_string()).unwrap());
+            attributes.insert(
+                String::from("z"),
+                to_value(self.stars[i].pt[2].to_string()).unwrap(),
+            );
             let f = Feature {
                 bbox: None,
                 geometry: Some(pt),
                 id: None,
-                properties: None, //Some(attributes),
+                properties: Some(attributes),
                 foreign_members: None,
             };
             fc.features.push(f);
